changeset 2462:d61e73357674

fix dynamic linking with google-test
author Sebastien Jodogne <s.jodogne@gmail.com>
date Fri, 05 Jan 2018 09:35:56 +0100
parents 47029de27a74
children be5c0f4155f6
files Resources/CMake/GoogleTestConfiguration.cmake
diffstat 1 files changed, 5 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/Resources/CMake/GoogleTestConfiguration.cmake	Thu Jan 04 20:02:35 2018 +0100
+++ b/Resources/CMake/GoogleTestConfiguration.cmake	Fri Jan 05 09:35:56 2018 +0100
@@ -56,12 +56,13 @@
 
 else()
   include(FindGTest)
-  if (NOT GOOGLE_TEST_FOUND)
+  if (NOT GTEST_FOUND)
     message(FATAL_ERROR "Unable to find GoogleTest")
   endif()
 
-  include_directories(${GOOGLE_TEST_INCLUDE_DIRS})
+  include_directories(${GTEST_INCLUDE_DIRS})
 
-  # The variable GOOGLE_TEST_LIBRARIES contains the shared library of
-  # Google Test
+  # The variable GTEST_LIBRARIES contains the shared library of
+  # Google Test, create an alias for more uniformity
+  set(GOOGLE_TEST_LIBRARIES ${GTEST_LIBRARIES})
 endif()